@@ -85,7 +85,6 @@ typedef struct {
 	gpointer cb2;
 	gpointer cbdata2;
 	gchar *url;
-	gchar *host;
 	SoupAddress *addr;
 	pCallback callback;
 	gpointer data;
@@ -110,11 +109,11 @@ got_chunk_blocking_cb(SoupMessage *msg, SoupBuffer *chunk, CallbackInfo *info) {
 	const char* clen;
 
 	if (info->total == 0) {
-#if LIBSOUP_VERSION < 2003000
+#if LIBSOUP_VERSION < 2048000
 		clen = soup_message_get_header(msg->response_headers,
 			"Content-length");
 #else
-		clen = soup_message_headers_get(msg->response_headers,
+		clen = soup_message_headers_get_one(msg->response_headers,
 			"Content-length");
 #endif
 		if (!clen)
@@ -138,8 +137,13 @@ got_chunk_cb(SoupMessage *msg, SoupBuffer *chunk, CallbackInfo *info) {
 	NetStatusProgress *progress = NULL;
 	const char* clen;
 
+#if LIBSOUP_VERSION < 2048000
 	clen = soup_message_headers_get(msg->response_headers,
 			"Content-length");
+#else
+	clen = soup_message_headers_get_one(msg->response_headers,
+			"Content-length");
+#endif
 	if (!clen)
 		info->total = 0;
 	else
@@ -351,7 +355,7 @@ rss_resolve_callback (SoupAddress *addr, guint status, gpointer data)
 	STNET *stnet = (STNET *)data;
 	SoupURI *proxy_uri = NULL;
 	if (status == SOUP_STATUS_OK) {
-		if (rss_ep_need_proxy_http (proxy, stnet->host, stnet->addr)) {
+		if (rss_ep_need_proxy_http (proxy, soup_address_get_name (stnet->addr), stnet->addr)) {
 #if (DATASERVER_VERSION >=2026000)
 			proxy_uri = e_proxy_peek_uri_for (proxy, stnet->url);
 #else
@@ -428,7 +432,6 @@ proxify_session_async(EProxy *proxy, STNET *stnet)
 #endif
 	case 2:
 		su = soup_uri_new (stnet->url);
-		stnet->host = su->host;
 		if (su) {
 			if (su->scheme == SOUP_URI_SCHEME_HTTPS) {
 				if (rss_ep_need_proxy_https (proxy, su->host)) {
@@ -754,7 +757,11 @@ redirect_handler (SoupMessage *msg, gpointer user_data)
 		SoupURI *new_uri;
 		const gchar *new_loc;
 
+#if LIBSOUP_VERSION < 2048000
 		new_loc = soup_message_headers_get (msg->response_headers, "Location");
+#else
+		new_loc = soup_message_headers_get_one (msg->response_headers, "Location");
+#endif
 		if (!new_loc)
 			return;
 
