@@ -44,6 +44,16 @@
 #endif
 #include <mail/em-event.h>
 
+#if (EVOLUTION_VERSION > 30501)
+#include <em-format/e-mail-formatter.h>
+#else
+#include <mail/em-format-html.h>
+#if EVOLUTION_VERSION >= 30400
+#include <mail/em-format-hook.h>
+#endif
+#endif
+#include <mail/e-mail-display.h>
+
 #ifdef HAVE_WEBKIT
 #include <webkit/webkitwebview.h>
 #endif
@@ -226,6 +236,7 @@ typedef struct _rssfeed {
 #define CONF_FEED_ICON "feed-icon"
 #define CONF_SHOW_COMMENTS "show-comments"
 #define CONF_SHOW_XML_ERRORS "show-xml-errors"
+#define CONF_SHOW_FEED_ERRORS "show-feed-errors"
 #endif
 
 enum {
@@ -236,6 +247,7 @@ enum {
 
 typedef struct ADD_FEED {
 	GtkWidget	*dialog;
+	GtkWidget	*dialog_aarea;
 	GtkWidget	*progress;
 	GtkWidget	*child;		//the dialog child
 	GtkBuilder	*gui;
@@ -339,6 +351,7 @@ typedef struct CREATE_FEED {	/* used by create_mail function when called by unbl
 	gchar *encl;		//feed enclosure
 	gchar *enclurl;
 	GList *attachments;	//feed media files
+	GHashTable *attlengths;	//feed media files
 	GList *attachedfiles;	//list of downloaded media files
 	guint attachmentsqueue;	//list of downloaded media files
 	FILE *efile;		//enclosure file
@@ -366,9 +379,6 @@ struct _rfMessage {
 };
 typedef struct _rfMessage rfMessage;
 
-guint ftotal;
-guint farticle;
-
 void compare_enabled(
 	gpointer key,
 	gpointer value,
@@ -456,6 +466,8 @@ gchar *generate_safe_chn_name(gchar *chn_name);
 void update_sr_message(void);
 void update_progress_text(gchar *title);
 void update_feed_image(RDF *r);
+void fetch_comments(gchar *url, gchar *mainurl, EMailDisplay *stream);
+gchar *print_comments(gchar *url, gchar *stream, EMailFormatter *format);
 void cancel_comments_session(SoupSession *sess);
 gchar *search_rss(char *buffer, int len);
 void prepare_hashes(void);
@@ -500,8 +512,8 @@ void download_chunk(
 	gpointer statusdata,
 	gpointer data);
 
-void process_enclosure(create_feed *CF);
-void process_attachments(create_feed *CF);
+gboolean process_enclosure(create_feed *CF);
+gboolean process_attachments(create_feed *CF);
 
 #ifdef HAVE_GECKO
 void rss_mozilla_init(void);
@@ -546,9 +558,12 @@ gboolean check_if_enabled (
 void free_filter_uids (gpointer user_data, GObject *ex_msg);
 #if EVOLUTION_VERSION >= 22900
 void quit_cb(void *ep, EShellView *shell_view);
+EShellView *rss_get_mail_shell_view (gboolean with_mail_reader);
 #endif
 void rebase_feeds(gchar *old_name, gchar *new_name);
 
+void rss_inc_farticle (void);
+void rss_inc_ftotal (void);
 
 #ifdef _WIN32
 char *strcasestr(const char *a, const char *b);
